package com.muyu.cloud.etl.controller;

import com.muyu.cloud.etl.service.SourceService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.Source;
import com.muyu.domain.req.SourceReq;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/source")
public class SourceController extends BaseController {

    @Autowired
    private SourceService sourceService;


    //列表
    @RequiresPermissions("etl:info:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Source>> list(SourceReq sourceReq) {
        startPage();
        List<Source> list = sourceService.selectSourceList(sourceReq);
        return getDataTable(list);
    }


    /*
     * 导出
     */
    @RequiresPermissions("etl:info:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SourceReq sourceReq) {
        List<Source> list=   sourceService.selectSourceList(sourceReq);
        ExcelUtil<Source> util = new ExcelUtil<>(Source.class);
        util.exportExcel(response,list,"基础信息");
    }

    /**
     * 获取基础信息详细信息
     */
    @RequiresPermissions("etl:info:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id) {
      Source source=  sourceService.getInfo(id);
      return success(source);
    }

    /**
     * 新增基础信息
     */
    @RequiresPermissions("etl:info:add")
    @PostMapping
    public Result add(@RequestBody Source sourceReq) {

        return toAjax(sourceService.insertBasicConfigInfo(sourceReq));
    }






}
